@@ -242,7 +242,7 @@ if [ "$NEEDS_SZIP" == "YES" ]
 then
 if [ "$USE_AEC" == "YES" ]
 then
-    if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libsz.${LD_EXT} ]
+    if [ "$FORCE" == "YES" ] || [ "$FORCE_SZIP" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libsz.${LD_EXT} ]
     then
         echo "${txtgrn}+++ SZIP (via libaec library)${txtrst}"
         szip_version="1.0.4"
@@ -284,7 +284,7 @@ then
         echo "${txtylw}+++ SZIP already installed.  Skipping download and installation.${txtrst}"
     fi
 else
-    if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libsz.${LD_EXT} ]
+    if [ "$FORCE" == "YES" ] || [ "$FORCE_SZIP" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libsz.${LD_EXT} ]
     then
         echo "${txtgrn}+++ SZIP${txtrst}"
         szip_version="2.1.1"
@@ -331,7 +331,7 @@ fi
 
 if [ "$NEEDS_ZLIB" == "YES" ]
 then
-    if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libz.${LD_EXT} ]
+    if [ "$FORCE" == "YES" ] || [ "$FORCE_ZLIB" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libz.${LD_EXT} ]
     then
         if [ "$USE_ZLIB_NG" == "YES" ]
         then
@@ -413,7 +413,7 @@ fi
 # =================== BUILD HDF5 ===============
 if [ "$HDF5" == "YES" ]
 then
-    if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libhdf5.${LD_EXT} ]
+    if [ "$FORCE" == "YES" ] || [ "$FORCE_HDF5" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libhdf5.${LD_EXT} ]
     then
 	hdf_suffix=""
 	if [ "${H5VERSION}" == "V110" ]; then
@@ -425,7 +425,7 @@ then
 	elif [ "${H5VERSION}" == "develop" ]; then
             hdf_version="develop"
 	else
-            echo 1>&2 ${txtred}Invalid HDF5 version specified: ${H5VERSION}.  Must be one of V110, V112, or V114. exiting.${txtrst}
+            echo 1>&2 ${txtred}Invalid HDF5 version specified: ${H5VERSION}.  Must be one of V110, V112, or V114 [default]. exiting.${txtrst}
             exit 1
 	fi
 
@@ -485,10 +485,10 @@ fi
 if [ "$PNETCDF" == "YES" ] && [ "$MPI" == "YES" ]
 then
     # PnetCDF currently only builds static library...
-    if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libpnetcdf.a ]
+    if [ "$FORCE" == "YES" ] || [ "$FORCE_PNETCDF" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libpnetcdf.a ]
     then
         echo "${txtgrn}+++ PnetCDF${txtrst}"
-        pnet_version="1.13.0"
+        pnet_version="1.14.0"
         pnet_base="pnetcdf"
         cd $ACCESS || exit
         cd TPL/pnetcdf || exit
@@ -534,12 +534,13 @@ fi
 # =================== INSTALL NETCDF ===============
 if [ "$NETCDF" == "YES" ]
 then
-if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libnetcdf.${LD_EXT} ]
+if [ "$FORCE" == "YES" ] || [ "$FORCE_NETCDF" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libnetcdf.${LD_EXT} ]
 then
 #   net_version="v4.9.1"
-    net_version="v4.9.2"
+#    net_version="v4.9.2"
+    net_version="v4.9.3"
 #   net_version="v4.8.1"
-#   net_version="master"
+#   net_version="main"
 
     echo "${txtgrn}+++ NetCDF ${net_version} ${txtrst}"
     cd $ACCESS || exit
@@ -551,6 +552,11 @@ then
         git clone --depth 1 --branch ${net_version} https://github.com/Unidata/netcdf-c netcdf-c
     fi
 
+    if [ "$net_version" == "v4.9.3" ]
+    then
+	PREFIX="NETCDF_"
+    fi
+
     if [ "$BUILD" == "YES" ]
     then
         echo "${txtgrn}+++ Configuring, Building, and Installing...${txtrst}"
@@ -562,7 +568,7 @@ then
 	then
            export HDF5_PLUGIN_PATH=${INSTALL_PATH}/lib/hdf5/lib/plugin
 	fi
-        CRAY=${CRAY} SHARED=${SHARED} DEBUG=${DEBUG} HDF5=${HDF5} NEEDS_ZLIB=${NEEDS_ZLIB} MPI=${MPI} bash -x ../../runcmake.sh
+        PREFIX=${PREFIX} CRAY=${CRAY} SHARED=${SHARED} DEBUG=${DEBUG} HDF5=${HDF5} NEEDS_ZLIB=${NEEDS_ZLIB} MPI=${MPI} bash -x ../../runcmake.sh
         if [[ $? != 0 ]]
         then
             echo 1>&2 ${txtred}couldn\'t configure cmake for NetCDF. exiting.${txtrst}
@@ -583,9 +589,9 @@ fi
 # =================== INSTALL CGNS ===============
 if [ "$CGNS" == "YES" ] && [ "$HDF5" == "YES" ]
 then
-    if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libcgns.${LD_EXT} ]
+    if [ "$FORCE" == "YES" ] || [ "$FORCE_CGNS" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libcgns.${LD_EXT} ]
     then
-	cgns_version="v4.4.0"
+	cgns_version="v4.5.0"
         echo "${txtgrn}+++ CGNS ${cgns_version} ${txtrst}"
         cd $ACCESS || exit
         cd TPL/cgns || exit
@@ -630,7 +636,7 @@ fi
 # =================== INSTALL METIS  ===============
 if [ "$METIS" == "YES" ]
 then
-    if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libmetis.a ]
+    if [ "$FORCE" == "YES" ] || [ "$FORCE_METIS" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libmetis.a ]
     then
         echo "${txtgrn}+++ Metis${txtrst}"
         cd $ACCESS || exit
@@ -672,7 +678,7 @@ fi
 # =================== INSTALL PARMETIS  ===============
 if [ "$PARMETIS" == "YES" ] && [ "$MPI" == "YES" ]
 then
-    if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libparmetis.a ]
+    if [ "$FORCE" == "YES" ] || [ "$FORCE_PARMETIS" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libparmetis.a ]
     then
         echo "${txtgrn}+++ ParMETIS${txtrst}"
         cd $ACCESS || exit
@@ -715,8 +721,8 @@ then
     check_exec automake
     check_exec autoconf
 
-    matio_version="v1.5.26"
-    if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libmatio.${LD_EXT} ]
+    matio_version="v1.5.28"
+    if [ "$FORCE" == "YES" ] || [ "$FORCE_MATIO" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libmatio.${LD_EXT} ]
     then
         echo "${txtgrn}+++ MatIO ${matio_version} ${txtrst}"
         cd $ACCESS || exit
@@ -756,9 +762,9 @@ fi
 # =================== INSTALL FMT ===============
 if [ "$FMT" == "YES" ]
 then
-    if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/include/fmt/core.h ]
+    if [ "$FORCE" == "YES" ] || [ "$FORCE_FMT" == "YES" ] || ! [ -e $INSTALL_PATH/include/fmt/core.h ]
     then
-        fmt_version="11.0.2"
+        fmt_version="11.1.2"
         echo "${txtgrn}+++ FMT ${fmt_version} ${txtrst}"
         cd $ACCESS || exit
         cd TPL/fmt || exit
@@ -799,9 +805,9 @@ fi
 # =================== INSTALL KOKKOS  ===============
 if [ "$KOKKOS" == "YES" ]
 then
-    if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libkokkoscore.${LD_EXT} ]
+    if [ "$FORCE" == "YES" ] || [ "$FORCE_KOKKOS" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libkokkoscore.${LD_EXT} ]
     then
-        kokkos_version="3.6.00"
+        kokkos_version="4.5.01"
         echo "${txtgrn}+++ KOKKOS${txtrst}"
         cd $ACCESS || exit
         cd TPL/kokkos || exit
@@ -809,9 +815,9 @@ then
         then
             echo "${txtgrn}+++ Downloading...${txtrst}"
             rm -rf kokkos
-            wget --no-check-certificate https://github.com/kokkos/kokkos/archive/${kokkos_version}.tar.gz
-            tar -zxf ${kokkos_version}.tar.gz
-            rm -f ${kokkos_version}.tar.gz
+            wget --no-check-certificate https://github.com/kokkos/kokkos/releases/download/${kokkos_version}/kokkos-${kokkos_version}.tar.gz
+            tar -zxf kokkos-${kokkos_version}.tar.gz
+            rm -f kokkos-${kokkos_version}.tar.gz
             ln -s kokkos-${kokkos_version} kokkos
         fi
 
@@ -844,7 +850,7 @@ fi
 # =================== INSTALL ADIOS2  ===============
 if [ "$ADIOS2" == "YES" ]
 then
-    if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libadios2_c.${LD_EXT} ]
+    if [ "$FORCE" == "YES" ] || [ "$FORCE_ADIOS2" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libadios2_c.${LD_EXT} ]
     then
 	adios2_version="v2.10.1"
         echo "${txtgrn}+++ ADIOS2 ${adios2_version} ${txtrst}"
@@ -886,7 +892,7 @@ fi
 # =================== INSTALL CATALYST2  ===============
 if [ "$CATALYST2" == "YES" ]
 then
-    if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libcatalyst.${LD_EXT} ]
+    if [ "$FORCE" == "YES" ] || [ "$FORCE_CATALYST2" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libcatalyst.${LD_EXT} ]
     then
         catalyst2_version="v2.0.0"
         echo "${txtgrn}+++ Catalyst2 ${catalyst2_version} ${txtrst}"
@@ -928,7 +934,7 @@ fi
 # =================== INSTALL gtest  ===============
 if [ "$GTEST" == "YES" ]
 then
-    if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libgtest.${LD_EXT} ]
+    if [ "$FORCE" == "YES" ] || [ "$FORCE_GTEST" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libgtest.${LD_EXT} ]
     then
         gtest_version="release-1.11.0"
         echo "${txtgrn}+++ gtest ${gtest_version} ${txtrst}"
@@ -970,9 +976,9 @@ fi
 # =================== INSTALL catch2  ===============
 if [ "$CATCH2" == "YES" ]
 then
-    if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libCatch2.a ]
+    if [ "$FORCE" == "YES" ] || [ "$FORCE_CATCH2" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libCatch2.a ]
     then
-        catch2_version="v3.5.3"
+        catch2_version="v3.8.0"
         echo "${txtgrn}+++ Catch2 ${catch2_version} ${txtrst}"
         cd $ACCESS || exit
         cd TPL/catch2 || exit
@@ -1012,7 +1018,7 @@ fi
 # =================== INSTALL PARALLEL  ===============
 if [ "$GNU_PARALLEL" == "YES" ]
 then
-    if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/bin/env_parallel ]
+    if [ "$FORCE" == "YES" ] || [ "$FORCE_GNU_PARALLEL" == "YES" ] || ! [ -e $INSTALL_PATH/bin/env_parallel ]
     then
         echo "${txtgrn}+++ GNU Parallel${txtrst}"
         cd $ACCESS || exit
@@ -1051,7 +1057,7 @@ fi
 # =================== INSTALL BOOST ===============
 if [ "$BOOST" == "YES" ]
 then
-  if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/include/boost ]
+  if [ "$FORCE" == "YES" ] || [ "$FORCE_BOOST" == "YES" ] || ! [ -e $INSTALL_PATH/include/boost ]
   then
     # FAODEL Requires Boost... For now, just download and install
     echo "${txtgrn}+++ Installing Boost as dependency of Faodel${txtrst}"
@@ -1078,7 +1084,7 @@ fi
 # =================== INSTALL FAODEL ===============
 if [ "$FAODEL" == "YES" ]
 then
-  if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libkelpie.${LD_EXT} ]
+  if [ "$FORCE" == "YES" ] || [ "$FORCE_FAODEL" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libkelpie.${LD_EXT} ]
   then
     faodel_base="faodel"
     echo "${txtgrn}+++ Faodel${txtrst}"
@@ -1120,7 +1126,7 @@ fi
 if [ "$FAODEL" == "YES" ]
 then
   # Currently, the FAODEL backend requires cereal, so if Faodel is enabled, we'll install cereal, too.
-  if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/include/cereal/archives/portable_binary.hpp ]
+  if [ "$FORCE" == "YES" ] || [ "$FORCE_FAODEL" == "YES" ] || ! [ -e $INSTALL_PATH/include/cereal/archives/portable_binary.hpp ]
   then
     echo "${txtgrn}+++ Cereal${txtrst}"
     cd $ACCESS || exit
